#region Copyright
/*
Copyright (c) 2008 EPiServer AB.  All rights reserved.

This code is released by EPiServer AB under the Source Code File - Specific License Conditions, published August 20, 2007. 
See http://www.episerver.com/Specific_License_Conditions for details. 
*/
#endregion

using System;
using System.Collections.Generic;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

using EPiServer.Core;
using EPiServer.Core.Html;
using EPiServer.DataAbstraction;

namespace EPiServer.Templates.Demo.Blog.Units
{
    /// <summary>
    /// A brief display of a blog item.
    /// </summary>
    public partial class ItemSummary : UserControlBase
    {
        private List<PageData> _tags;
        private PageData _blogStart;
        private PageData _selectedPage;
        private string _summaryText;
        private int _summaryTextLength = 250;
        private bool _showImage = true;
        private bool _showWriter = true;

        /// <summary>
        /// Checks if an image for the blogger exists, and if so, displays it.
        /// </summary>
        /// <param name="e">An <see cref="T:System.EventArgs"></see> object that contains the event data.</param>
        protected override void OnPreRender(EventArgs e)
        {
            base.OnPreRender(e);

            if (!String.IsNullOrEmpty((string)BlogStart["Image"]) && ShowImage)
            {
                BloggerLink.Visible = true;
                BloggerLink.HRef = BlogStart.LinkURL;
                BloggerImage.Src = BlogStart["Image"].ToString();
                BloggerImage.Alt = BlogStart["Writer"].ToString();
                ItemContentPanel.CssClass = "text";
            }
        }

        /// <summary>
        /// Strips any html tags from the MainBody property and reduces the lenght to 250 chars.
        /// </summary>
        /// <value>A string with the preview text.</value>
        protected string SummaryText
        {
            get 
            {
                if (String.IsNullOrEmpty(_summaryText))
                {
                    _summaryText = TextIndexer.StripHtml((String)SelectedPage["MainBody"], SummaryTextLength);
                }
                return _summaryText; 
            }
        }

        /// <summary>
        /// The number of characters to truncate the preview text to.
        /// </summary>
        public int SummaryTextLength
        {
            get { return _summaryTextLength; }
            set { _summaryTextLength = value; }
        }

        /// <summary>
        /// Defines wether to show the bloggers image.
        /// </summary>
        public bool ShowImage
        {
            get { return _showImage; }
            set { _showImage = value; }
        }

        /// <summary>
        /// Defines wether to show the writers name.
        /// </summary>
        public bool ShowWriter
        {
            get { return _showWriter; }
            set { _showWriter = value; }
        }

        /// <summary>
        /// The blog item to render
        /// </summary>
        public PageData SelectedPage
        {
            get 
            {
                if (_selectedPage == null)
                {
                    return CurrentPage;
                }
                return _selectedPage;
            }
            set { _selectedPage = value; }
        }

        /// <summary>
        /// The tags for the blog item
        /// </summary>
        protected List<PageData> Tags
        {
            get
            {
                if (_tags == null)
                {
                    _tags = new List<PageData>();
                    CategoryList cl = (CategoryList)SelectedPage["PageCategory"];

                    if (cl == null)
                    {
                        return _tags;
                    }

                    Category categoryTag;
                    PageDataCollection pdc = DataFactory.Instance.GetChildren((PageReference)BlogStart[BlogUtil.TagContainerPropertyName]);

                    foreach (int c in cl)
                    {
                        categoryTag = Category.Find(c);

                        foreach (PageData pd in pdc)
                        {
                            if (pd.PageName == categoryTag.Name)
                            {
                                _tags.Add(pd);
                            }
                        }
                    }
                }
                return _tags;
            }
        }

        /// <summary>
        /// Gets the blog start page.
        /// </summary>
        public PageData BlogStart
        {
            get 
            {
                if (_blogStart == null) 
                {
                    _blogStart = DataFactory.Instance.GetPage((PageReference)SelectedPage[BlogUtil.StartPropertyName]);
                }
                return _blogStart;
            }  
        }
    }
}