#region Copyright
/*
Copyright (c) 2008 EPiServer AB.  All rights reserved.

This code is released by EPiServer AB under the Source Code File - Specific License Conditions, published August 20, 2007. 
See http://www.episerver.com/Specific_License_Conditions for details. 
*/
#endregion

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Web.Hosting;

using EPiServer.Demo.FileManager;
using EPiServer.Demo.FileManager.WebControls;
using EPiServer.Web.Hosting;

namespace EPiServer.Templates.Demo.FileManager
{
    /// <summary>
    /// Displays a list of sub directories in the current <see cref="FileManagerControl.CurrentVirtualDirectory"/>
    /// </summary>
    public partial class FolderList : ContentUserControlBase
    {
        bool _isDataBound = false;

        /// <summary>
        /// Raises the <see cref="E:System.Web.UI.Control.Init"/> event.
        /// </summary>
        /// <param name="e">An <see cref="T:System.EventArgs"/> object that contains the event data.</param>
        protected override void OnInit(EventArgs e)
        {
            base.OnInit(e);
            // Listen to Filemanager commands to update if a change occurs.
            FileManager.CommandExecuted += new EventHandler<FileManagerCommandEventArgs>(FileManager_CommandExecuted);
        }
        
        /// <summary>
        /// Raises the <see cref="E:System.Web.UI.Control.PreRender"/> event.
        /// </summary>
        /// <param name="e">An <see cref="T:System.EventArgs"/> object that contains the event data.</param>
        protected override void OnPreRender(EventArgs e)
        {
            base.OnPreRender(e);
            // If the file list hasn't been data bound yet then this is our last chance.
            if (!_isDataBound)
            {
                DataBindFileList();
            }
        }

        /// <summary>
        /// Sets the collection of sub directories as datasource to the folder list and databinds it.
        /// </summary>
        private void DataBindFileList() 
        {
            if (FileManager.CurrentVirtualDirectory != null)
            {
                FolderRepeater.DataSource = FileManager.CurrentVirtualDirectory.GetDirectories();
                FolderRepeater.DataBind();
                _isDataBound = true;
            }
        }

        /// <summary>
        /// Handles the CommandExecuted event of the FileManager control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="EPiServer.Demo.FileManager.FileManagerCommandEventArgs"/> instance containing the event data.</param>
        private void FileManager_CommandExecuted(object sender, FileManagerCommandEventArgs e)
        {
            // Reload the folder list if a new folder is selected.
            if (e.CommandName == FileManagerCommandName.SelectFolder)
            {
                DataBindFileList();
            }
        }

        /// <summary>
        /// Raises a command in the <see cref="FileManager"/> based on the arguments submitted.
        /// </summary>
        /// <param name="sender">The sender raising the command.</param>
        /// <param name="e">The <see cref="System.Web.UI.WebControls.CommandEventArgs"/> instance containing the event data.</param>
        protected void RaiseCommand(object sender, CommandEventArgs e)
        {
            if (String.Equals(e.CommandArgument, "ParentFolder"))
            {
                if (FileManager.CurrentVirtualDirectory.Parent == null)
                {
                    return;
                }
                FileManager.RaiseCommand(this, new FileManagerCommandEventArgs(e.CommandName, FileManager.CurrentVirtualDirectory.Parent.VirtualPath));
            }
            else
            {
                FileManager.RaiseCommand(this, new FileManagerCommandEventArgs(e.CommandName, e.CommandArgument));
            }
            
            FileManager.LoadDefaultView(this);
        }

        /// <summary>
        /// Gets a value indicating whether the current folder is the same as the root folder.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this folder is root folder; otherwise, <c>false</c>.
        /// </value>
        protected bool IsRootLevel
        {
            get
            {
                return FileManager.CurrentVirtualPath == FileManager.RootVirtualPath;
            }
        }
    }
}