#region Copyright
/*
Copyright (c) 2008 EPiServer AB.  All rights reserved.

This code is released by EPiServer AB under the Source Code File - Specific License Conditions, published August 20, 2007. 
See http://www.episerver.com/Specific_License_Conditions for details. 
*/
#endregion

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using EPiServer.Demo.FileManager;
using EPiServer.Demo.FileManager.WebControls;
using EPiServer.Security;
using EPiServer.Web.WebControls;

namespace EPiServer.Templates.Demo.FileManager
{
    /// <summary>
    /// Displays a button bar for changing the active view.
    /// </summary>
    public partial class SwitchViewContent : ContentUserControlBase
    {
        /// <summary>
        /// Raises the <see cref="E:System.Web.UI.Control.Init"/> event.
        /// </summary>
        /// <param name="e">An <see cref="T:System.EventArgs"/> object that contains the event data.</param>
        protected override void OnInit(EventArgs e)
        {
            base.OnInit(e);
            FileManager.SelectedItems.CollectionChanged += new VirtualFileBaseCollection.CollectionChangedEventHandler(SelectedItems_Changed);
            FileManager.PasteBuffer.CollectionChanged += new VirtualFileBaseCollection.CollectionChangedEventHandler(SelectedItems_Changed);
        }

        /// <summary>
        /// Raises the <see cref="E:System.Web.UI.Control.Load"/> event.
        /// </summary>
        /// <param name="e">The <see cref="T:System.EventArgs"/> object that contains the event data.</param>
        protected override void OnLoad(EventArgs e)
        {
            base.OnLoad(e);
            if (!IsPostBackView)
            {
                EnableButtons();
            }
        }

        /// <summary>
        /// Handles the Changed event of the SelectedItems collection to update button state when file selection changes.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="EPiServer.Demo.FileManager.CollectionChangedEventArgs"/> instance containing the event data.</param>
        private void SelectedItems_Changed(object sender, CollectionChangedEventArgs e)
        {
            EnableButtons();
        }

        /// <summary>
        /// Handles the Command event of the Button controls to change the current view.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.Web.UI.WebControls.CommandEventArgs"/> instance containing the event data.</param>
        protected void Button_Command(object sender, CommandEventArgs e)
        {
            try
            {
                LinkButton clickedButton = (LinkButton)sender;
                if (clickedButton == AddFile || clickedButton == AddFolder)
                {
                    FileManager.SelectedItems.Clear();
                }
                FileManager.RaiseCommand(this, new FileManagerCommandEventArgs(e.CommandName, e.CommandArgument));
            }
            catch (UnauthorizedAccessException)
            {
                //TODO: Fix more fine grained error handling.
                Page.Validators.Add(new StaticValidator(Translate("/filemanager/errormessage/insufficientaccess")));
            }
            catch (ArgumentException ae)
            {
                Page.Validators.Add(new StaticValidator(ae.Message));
            }
        }

        /// <summary>
        /// Changes the enabled state of buttons based on current file manager state.
        /// </summary>
        private void EnableButtons()
        {
            Rename.Enabled = (FileManager.SingleSelectedItem != null);
            Details.Enabled = (FileManager.SingleSelectedFile != null);
            Paste.Enabled = (FileManager.PasteBuffer.Count > 0);
            Cut.Enabled = (FileManager.SelectedItems.Count > 0);
            Copy.Enabled = (FileManager.SelectedItems.Count > 0);
            Delete.Enabled = (FileManager.SelectedItems.Count > 0);
            
            if (!FileManager.CurrentVirtualDirectory.QueryDistinctAccess(AccessLevel.Create | AccessLevel.Edit | AccessLevel.Delete))
            {
                DisabledFunctionsMessage.Visible = true;
                AddFile.Enabled = false;
                AddFolder.Enabled = false;
                Rename.Enabled = false;
                Delete.Enabled = false;
                Cut.Enabled = false;
                Paste.Enabled = false;
            }
            if (FileManager.SingleSelectedFile != null)
            {
                View.Enabled = true;
                View.Target = "_blank";
                View.NavigateUrl = FileManager.SingleSelectedFile.VirtualPath;
            }
            else 
            {
                View.Enabled = false;
                View.NavigateUrl = String.Empty;
            }
        }
    }
}
