#region Copyright
/*
Copyright (c) 2008 EPiServer AB.  All rights reserved.

This code is released by EPiServer AB under the Source Code File - Specific License Conditions, published August 20, 2007. 
See http://www.episerver.com/Specific_License_Conditions for details. 
*/
#endregion

using System;
using System.Web;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;

using EPiServer;

namespace EPiServer.Templates.Demo.Units.Placeable
{
	/// <summary>
	/// Rotates the content of a page collection
    /// displaying the PageName and MainBody properties of each page.
	/// </summary>
	public partial class PageRoller : UserControlBase
	{
        // "ListingSlideContainer" (PropertyPageReference)[Required] defines the root page to fetch pages for the slide.
        
        // "ListingSlideCount" (PropertyNumber)[Optional, Default value=-1 (list all pages)] defines the number of pages to show. 
        private static readonly string _listingSlideCountPropertyName = "ListingSlideCount";
        
        // "RefreshRate" (PropertyNumber)[Optional, Default value=10] defines the number of seconds between slide change.
        private static readonly string _refreshRatePropertyName = "RefreshRate";
        
        
        
        private bool _isFirstSlide = true;

        /// <summary>
        /// Raises the <see cref="E:System.Web.UI.Control.Load"></see> event.
        /// </summary>
        /// <param name="e">The <see cref="T:System.EventArgs"></see> object that contains the event data.</param>
        protected override void OnLoad(EventArgs e)
        {
            base.OnLoad(e);
            if (!IsPostBack)
            {
                PageListControl.DataBind();
            }
        }

        /// <summary>
        /// Gets the number of pages to show in the slide.
        /// </summary>
        /// <returns></returns>
        protected int GetCount()
		{
            object listingSlideCount = CurrentPage[_listingSlideCountPropertyName];
            if (listingSlideCount != null)
            {
                return (int)listingSlideCount;
            }
			return -1;
		}

        /// <summary>
        /// Gets the number of seconds between slide changes.
        /// </summary>
        /// <returns></returns>
        protected int GetRefreshRate
        {
            get 
            {
                object refreshRate = CurrentPage[_refreshRatePropertyName];
                if (refreshRate != null)
                {
                    return (int)refreshRate;
                }
                // Default is 10 seconds
                return 10;
            }
        }

        /// <summary>
        /// Gets the className every slide should have initially.
        /// </summary>
        /// <returns></returns>
		protected string GetClassName()
		{
			if(_isFirstSlide)
			{
				_isFirstSlide = false;
				return string.Empty;
			}
			return "hidden";
		}
    }
}
