#region Copyright
/*
Copyright (c) 2008 EPiServer AB.  All rights reserved.

This code is released by EPiServer AB under the Source Code File - Specific License Conditions, published August 20, 2007. 
See http://www.episerver.com/Specific_License_Conditions for details. 
*/
#endregion

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

namespace EPiServer.Templates.Demo.WebParts.Units
{
    /// <summary>
    /// Displays an RSS-feed
    /// </summary>
    public partial class RssControl : System.Web.UI.UserControl, System.Web.UI.WebControls.WebParts.IWebPart
    {
        private string _catalogIconImageUrl;
        private string _description;
        private string _subtitle;
        private string _title;
        private string _titleIconImageUrl;
        private string _titleUrl;

        /// <summary>
        /// Gets or sets the SRC uri.
        /// </summary>
        /// <value>The SRC.</value>
        [Personalizable]
        [WebBrowsable]
        public Uri Src
        {
            get { return RssRenderer.Src; }
            set 
            {
                // this setter will be called by ApplyChanges of the PropertyGridEditorPart which will swallow any exception.
                // In order to prevent invalid uris to be passed down to the underlying RssControl we need to check for exceptions ourselves.
                string x = null;
                try
                {
                    x = value.AbsoluteUri;
                }
                catch (InvalidOperationException e)
                {
                    RssRenderer.Src = null;
                    throw new EPiServer.Core.EPiServerException("Url cannot be empty.", "/templates/webparts/units/rsscontrol/emptyurl", e);
                }

                RssRenderer.Src = value; 
            }
        }

        /// <summary>
        /// Gets or sets the item count.
        /// </summary>
        /// <value>The item count.</value>
        [Personalizable]
        [WebBrowsable]
        public int ItemCount
        {
            get { return RssRenderer.ItemCount; }
            set { RssRenderer.ItemCount = value; }
        }

        #region IWebPart Members
        // IWebPart members do not need the Personalizable

        /// <summary>
        /// Gets or sets the URL to an image that represents a <see cref="T:System.Web.UI.WebControls.WebParts.WebPart"/> control in a catalog of controls.
        /// </summary>
        /// <value></value>
        /// <returns>A string that represents the URL to an image used to represent the control in a catalog. The default value is an empty string ("").</returns>
        public string CatalogIconImageUrl
        {
            get { return _catalogIconImageUrl; }
            set { _catalogIconImageUrl = value; }
        }

        /// <summary>
        /// Gets or sets a brief phrase that summarizes what a control does, for use in ToolTips and catalogs of <see cref="T:System.Web.UI.WebControls.WebParts.WebPart"/> controls.
        /// </summary>
        /// <value></value>
        /// <returns>A string that briefly summarizes the control's functionality. The default value is an empty string ("").</returns>
        public string Description
        {
            get { return _description; }
            set { _description = value; }
        }

        /// <summary>
        /// Gets a string that is concatenated with the <see cref="P:System.Web.UI.WebControls.WebParts.IWebPart.Title"/> property value to form a complete title for a <see cref="T:System.Web.UI.WebControls.WebParts.WebPart"/> control.
        /// </summary>
        /// <value></value>
        /// <returns>A string that serves as a subtitle for the control. The default value is an empty string ("").</returns>
        public string Subtitle
        {
            get { return _subtitle; }
            set { _subtitle = value; }
        }

        /// <summary>
        /// Gets or sets the title of a <see cref="T:System.Web.UI.WebControls.WebParts.WebPart"/> control.
        /// </summary>
        /// <value></value>
        /// <returns>A string that contains the title of the control. The default value is an empty string ("").</returns>
        [WebBrowsable]
        public string Title
        {
            get
            {
                // if no value is present return the title of the feed.
                if (_title == null)
                {
                    return RssRenderer.Title;
                }
                return _title;
            }
            set
            {
                // reset the value if empty string is passed

                _title = value != null && value.Trim().Length > 0 ? value : null;
            }
        }

        /// <summary>
        /// Gets or sets the URL to an image used to represent a Web Parts control in the control's own title bar.
        /// </summary>
        /// <value></value>
        /// <returns>A string that represents the URL to an image. The default value is an empty string ("").</returns>
        public string TitleIconImageUrl
        {
            get { return _titleIconImageUrl; }
            set { _titleIconImageUrl = value; }
        }

        /// <summary>
        /// Gets or sets a URL to supplemental information about a <see cref="T:System.Web.UI.WebControls.WebParts.WebPart"/> control.
        /// </summary>
        /// <value></value>
        /// <returns>A string that represents a URL to more information about a <see cref="T:System.Web.UI.WebControls.WebParts.WebPart"/> control. The default value is an empty string ("").</returns>
        public string TitleUrl
        {
            get { return _titleUrl; }
            set { _titleUrl = value; }
        }
        #endregion
    }
}