#region Copyright
/*
Copyright (c) 2008 EPiServer AB.  All rights reserved.

This code is released by EPiServer AB under the Source Code File - Specific License Conditions, published August 20, 2007. 
See http://www.episerver.com/Specific_License_Conditions for details. 
*/
#endregion

using System;
using System.Data;
using System.Configuration;
using System.Reflection;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using EPiServer.WebParts.WebControls;

namespace EPiServer.Templates.Demo.WebParts.Units
{
    /// <summary>
    /// RssZone adds functionality to ExtendedWebPartZone 
    /// to allow for drag and drop of RSS URI's
    /// </summary>
    public class RssZone : ExtendedWebPartZone
    {

        /// <summary>
        /// Raises the <see cref="E:System.Web.UI.Control.PreRender"/> event.
        /// </summary>
        /// <param name="e">An <see cref="T:System.EventArgs"/> that contains the event data.</param>
        protected override void OnPreRender(EventArgs e)
        {
            EnsureChildControls();

            this.Attributes["ondragenter"] = "onDragEnter(this)";
            this.Attributes["ondragover"] = "onDragOver(this)";
            this.Attributes["ondrop"] = "onDrop('" + this.ClientID + "')";

            base.OnPreRender(e);
        }

        /// <summary>
        /// Raises the <see cref="E:System.Web.UI.Control.Load"/> event.
        /// </summary>
        /// <param name="e">The <see cref="T:System.EventArgs"/> object that contains the event data.</param>
        protected override void OnLoad(EventArgs e)
        {
            // register rss clientscript support
            if (!this.Page.ClientScript.IsClientScriptIncludeRegistered(typeof(ExtendedWebPartZone), "Rss"))
            {
                this.Page.ClientScript.RegisterClientScriptInclude(typeof(ExtendedWebPartZone), "Rss", EPiServer.UriSupport.ResolveUrlBySettings(@"~/templates/Demo/WebParts/Units/javascripts/Rss.js"));
            }

            // check to see if there is a posted rss-url to pick up
            if (this.WebPartProperty == null && this.Page.Request.Form["__zone"] == this.ClientID)
            {
                Uri uri = null;
                bool validDrop;
                try
                {
                    uri = new Uri(this.Page.Request.Form["__rss"]);
                    validDrop = true;
                }
                catch
                {
                    validDrop = false;
                    this.Page.ClientScript.RegisterStartupScript(typeof(RssZone), "InvalidRss", "alert('Invalid RSS');", true);
                }

                if (validDrop)
                {
                    RssControl rss = (RssControl)this.Page.LoadControl("~/templates/Demo/WebParts/Units/RssControl.ascx");
                    rss.Src = uri;
                    rss.ID = "rss";
                    GenericWebPart webPart = this.WebPartManager.CreateWebPart(rss);
                    this.WebPartManager.AddWebPart(webPart, this, 0);
                }
            }

            base.OnLoad(e);
        }
    }
}