#region Copyright
/*
Copyright (c) 2008 EPiServer AB.  All rights reserved.

This code is released by EPiServer AB under the Source Code File - Specific License Conditions, published August 20, 2007. 
See http://www.episerver.com/Specific_License_Conditions for details. 
*/
#endregion

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.ComponentModel;
using EPiServer.Security;
using EPiServer.Core;
using EPiServer.Templates.Demo.Workroom.Core;

namespace EPiServer.Templates.Demo.Workroom.Units
{
    /// <summary>
    /// Renders the content of a property and buttons to edit the property if the user has publish permissions to the current page
    /// </summary>
    public partial class EditableContent : EPiServer.UserControlBase
    {
        /// <summary>
        /// Raises the <see cref="E:System.Web.UI.Control.Load"/> event.
        /// </summary>
        /// <param name="e">The <see cref="T:System.EventArgs"/> object that contains the event data.</param>
        protected override void OnLoad(EventArgs e)
        {
            base.OnLoad(e);
            //TODO: Use Workroom security helpers when implemented.
            if (WorkroomPageBase.QueryDistinctMembershipLevel(MembershipLevel.Modify))
            {
                EditContent.Visible = true;
            }
        }


        /// <summary>
        /// Gets the workroom page base.
        /// </summary>
        /// <value>The workroom page base.</value>
        protected Core.WorkroomPageBase WorkroomPageBase
        {
            get 
            {
                return (Core.WorkroomPageBase)Page;
            }
        }

        /// <summary>
        /// Gets or sets the name of the property to show edit.
        /// </summary>
        [Category("Appearance"), DefaultValue(""), Bindable(true)]
        public string PropertyName
        {
            get { return ContentProperty.PropertyName; }
            set { ContentProperty.PropertyName = value; }
        }

        /// <summary>
        /// Gets or sets the page to editable state and toggles visibility of member controls to reflect the new state.
        /// </summary>
        /// <value><c>true</c> if the page is in editable state; otherwise, <c>false</c>.</value>
        protected bool EditEnabled
        {
            get
            {
                return WorkroomPageBase.EditableContent;
            }
            set
            {
                // Set edit mode state on the page hosting this control.
                WorkroomPageBase.EditableContent = true;

                // Make the content property control render its edit controls
                ContentProperty.EditMode = value;
                ContentLabel.Visible = value;

                // Toggle visibility state of button controls
                EditContent.Visible = !value;

                SaveContent.Visible = value;
                CancelEdit.Visible = value;
            }
        }

        #region Button Click Event Handlers

        /// <summary>
        /// Stst the content control to editable state and shows save and cancel buttons.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void EditContent_Click(object sender, EventArgs e)
        {
            EditEnabled = true;
        }

        /// <summary>
        /// Saves the updated content and publishes the current page. 
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void SaveContent_Click(object sender, EventArgs e)
        {
            PageBase.SavePageHandler.RequestedSaveAction = EPiServer.DataAccess.SaveAction.Publish;
            if (PageBase.SavePage())
            {
                EditEnabled = false;
                ContentProperty.DataBind();
            }
        }


        /// <summary>
        /// Cancels the editable state of the property and restores button visibility state.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void CancelEdit_Click(object sender, EventArgs e)
        {
            EditEnabled = false;
            ContentProperty.DataBind();
        }

        #endregion

    }
}